```{include} ../../README.md

```

## Feedback

If you encounter any errors or problems with **intake-esm**, please open an issue at the GitHub [main repository](http://github.com/NCAR/intake-esm).

## Documentation Contents

```{toctree}
---
maxdepth: 2
caption: Using intake-esm
---
installation.md
user-guide/index.md
supplemental-guide/index.md
```

```{toctree}
---
maxdepth: 2
caption: Reference and contributing
---
api.md
contributing.md
changelog.md
```
